load method

  1. @override
Future<WidgetsLocalizations> load(
  1. Locale locale
)
override

Start loading the resources for locale. The returned future completes when the resources have finished loading.

It's assumed that this method will return an object that contains a collection of related string resources (typically defined with one method per resource). The object will be retrieved with Localizations.of.

Implementation

@override
Future<WidgetsLocalizations> load(Locale locale) {
  final String lang = getLang(locale);
  switch (lang) {

    case "en":
      return new SynchronousFuture<WidgetsLocalizations>(const en());

    default:
      return new SynchronousFuture<WidgetsLocalizations>(const S());
  }
}