createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
DiscoveryStateChange createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
DiscoveryStateChange createEmptyInstance() => create();