createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
RequestPermissionResult createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
RequestPermissionResult createEmptyInstance() => create();