createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
SocketMessage createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
SocketMessage createEmptyInstance() => create();